cal.RemoteCalendar (Remote Calendar) — amici1

# `cal.RemoteCalendar` (Remote Calendar)

RemoteCalendar(id, seqno, type, url_template, username, password, readonly)

Master tables : cal.RemoteCalendars (Remote Calendars)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- No. (seqno) : The sequence number of this item with its parent.

- Type (type) : See `<django.db.models.fields.CharField: type>`.

- URL template (url_template) : See `<django.db.models.fields.CharField: url_template>`.

- Username (username) : See `<django.db.models.fields.CharField: username>`.

- Password (password) : See `<lino.core.fields.PasswordField: password>`.

- read-only (readonly) : See `<django.db.models.fields.BooleanField: readonly>`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

- Name (name_column) : See `lino_xl.lib.cal.models.RemoteCalendar.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.RemoteCalendar.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.RemoteCalendar.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
seqno | No. | The sequence number of this item with its parent.
type | Type |
url_template | URL template |
username | Username |
password | Password |
readonly | read-only |
move_buttons | Move | Displays buttons for certain actions on this row:
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |